==> croud-0.19.1.tar.gz: croud-0.19.1/croud/projects/users/commands.py <==
# Licensed to CRATE Technology GmbH ("Crate") under one or more contributor
# license agreements.  See the NOTICE file distributed with this work for
# additional information regarding copyright ownership.  Crate licenses
# this file to you under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.  You may
# obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
# License for the specific language governing permissions and limitations
# under the License.
#
# However, if you have executed another commercial license agreement
# with Crate these terms will supersede the license and you may use the
# software solely pursuant to the terms of the relevant commercial agreement.

from argparse import Namespace

from croud.config import get_output_format
from croud.printer import print_response
from croud.rest import Client
from croud.session import RequestMethod


def project_users_add(args: Namespace) -> None:
    """
    Adds a user to a project.
    """

    client = Client.from_args(args)

    data, errors = client.send(
        RequestMethod.POST,
        f"/api/v2/projects/{args.project_id}/users/",
        body={"user": args.user, "role_fqn": args.role},
    )
    if data is not None and data.get("added", False):
        success_message = "User added to project."
    else:
        success_message = "Role altered for user."

    print_response(
        data=data,
        errors=errors,
        keys=["user_id", "project_id", "role_fqn"],
        success_message=success_message,
        output_fmt=get_output_format(args),
    )


def role_fqn_transform(field):
    return field[0]["role_fqn"]


def project_users_list(args: Namespace) -> None:
    """
    Lists project users
    """

    client = Client.from_args(args)
    data, errors = client.send(
        RequestMethod.GET, f"/api/v2/projects/{args.project_id}/users/"
    )
    print_response(
        data=data,
        errors=errors,
        output_fmt=get_output_format(args),
        keys=["uid", "email", "username", "project_roles"],
        transforms=[None, None, None, role_fqn_transform],
    )


def project_users_remove(args: Namespace) -> None:
    """
    Removes a user from a project.
    """

    client = Client.from_args(args)
    data, errors = client.send(
        RequestMethod.DELETE, f"/api/v2/projects/{args.project_id}/users/{args.user}/"
    )
    print_response(
        data=data,
        errors=errors,
        success_message="User removed from project.",
        output_fmt=get_output_format(args),
    )

==> croud-0.21.0.tar.gz: croud-0.21.0/croud/projects/users/commands.py <==
# Licensed to CRATE Technology GmbH ("Crate") under one or more contributor
# license agreements.  See the NOTICE file distributed with this work for
# additional information regarding copyright ownership.  Crate licenses
# this file to you under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.  You may
# obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
# License for the specific language governing permissions and limitations
# under the License.
#
# However, if you have executed another commercial license agreement
# with Crate these terms will supersede the license and you may use the
# software solely pursuant to the terms of the relevant commercial agreement.

from argparse import Namespace

from croud.api import Client
from croud.config import get_output_format
from croud.printer import print_response


def project_users_add(args: Namespace) -> None:
    """
    Adds a user to a project.
    """

    client = Client.from_args(args)

    data, errors = client.post(
        f"/api/v2/projects/{args.project_id}/users/",
        body={"user": args.user, "role_fqn": args.role},
    )
    if data is not None and data.get("added", False):
        success_message = "User added to project."
    else:
        success_message = "Role altered for user."

    print_response(
        data=data,
        errors=errors,
        keys=["user_id", "project_id", "role_fqn"],
        success_message=success_message,
        output_fmt=get_output_format(args),
    )


def role_fqn_transform(field):
    return field[0]["role_fqn"]


def project_users_list(args: Namespace) -> None:
    """
    Lists project users
    """

    client = Client.from_args(args)
    data, errors = client.get(f"/api/v2/projects/{args.project_id}/users/")
    print_response(
        data=data,
        errors=errors,
        output_fmt=get_output_format(args),
        keys=["uid", "email", "username", "project_roles"],
        transforms=[None, None, None, role_fqn_transform],
    )


def project_users_remove(args: Namespace) -> None:
    """
    Removes a user from a project.
    """

    client = Client.from_args(args)
    data, errors = client.delete(
        f"/api/v2/projects/{args.project_id}/users/{args.user}/"
    )
    print_response(
        data=data,
        errors=errors,
        success_message="User removed from project.",
        output_fmt=get_output_format(args),
    )
